==> camunda-engine-7.4.0-sources.jar: org/camunda/bpm/engine/impl/cmd/GetHistoricJobLogExceptionStacktraceCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmd;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;

import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;
import org.camunda.bpm.engine.impl.persistence.entity.AuthorizationManager;
import org.camunda.bpm.engine.impl.persistence.entity.HistoricJobLogEventEntity;

/**
 * @author Roman Smirnov
 *
 */
public class GetHistoricJobLogExceptionStacktraceCmd implements Command<String> {

  protected String historicJobLogId;

  public GetHistoricJobLogExceptionStacktraceCmd(String historicJobLogId) {
    this.historicJobLogId = historicJobLogId;
  }

  public String execute(CommandContext commandContext) {
    ensureNotNull("historicJobLogId", historicJobLogId);

    HistoricJobLogEventEntity job = commandContext
        .getHistoricJobLogManager()
        .findHistoricJobLogById(historicJobLogId);

    ensureNotNull("No historic job log found with id " + historicJobLogId, "historicJobLog", job);

    AuthorizationManager authorizationManager = commandContext.getAuthorizationManager();
    authorizationManager.checkReadHistoricJobLog(job);

    return job.getExceptionStacktrace();
  }

}

==> camunda-engine-7.10.0-sources.jar: org/camunda/bpm/engine/impl/cmd/GetHistoricJobLogExceptionStacktraceCmd.java <==
/*
 * Copyright © 2012 - 2018 camunda services GmbH and various authors (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmd;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;

import org.camunda.bpm.engine.impl.cfg.CommandChecker;
import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;
import org.camunda.bpm.engine.impl.persistence.entity.HistoricJobLogEventEntity;

/**
 * @author Roman Smirnov
 *
 */
public class GetHistoricJobLogExceptionStacktraceCmd implements Command<String> {

  protected String historicJobLogId;

  public GetHistoricJobLogExceptionStacktraceCmd(String historicJobLogId) {
    this.historicJobLogId = historicJobLogId;
  }

  public String execute(CommandContext commandContext) {
    ensureNotNull("historicJobLogId", historicJobLogId);

    HistoricJobLogEventEntity job = commandContext
        .getHistoricJobLogManager()
        .findHistoricJobLogById(historicJobLogId);

    ensureNotNull("No historic job log found with id " + historicJobLogId, "historicJobLog", job);

    for(CommandChecker checker : commandContext.getProcessEngineConfiguration().getCommandCheckers()) {
      checker.checkReadHistoricJobLog(job);
    }

    return job.getExceptionStacktrace();
  }

}
